@@ -6,9 +6,11 @@ import qualified GI.GLib.Config as GLib
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "GObject"
         version = "2.0"
+        pkgName = "gi-gobject"
+        pkgVersion = "2.0.27"
         overridesFile = Just "GObject.overrides"
         verbose = False
         outputDir = Nothing
